@@ -1,8 +1,6 @@
 package t::ToolSet::ExportBadType;
 use base 'ToolSet';
 
-ToolSet->export(
-    'Carp' => {},
-);
+ToolSet->export( 'Carp' => {}, );
 
 1; # return true
